@@ -176,7 +176,8 @@ class SVMONReport:
             serviceVersionIterator=0
             for serviceIterator in range(len(self.service_names)):
                 if serviceVersionIterator < len(self.tags) and self.tags[serviceVersionIterator] != None and self.tags[serviceVersionIterator] != "" :
-                    res.append(self.site+'\t'+self.host+'\t'+self.operating_system+'\t'+self.service_type+'\t'+self.service_names[serviceIterator]+'\t'+self.tags[serviceVersionIterator]+'\n')
+                    tagsDecoded = self.tags[serviceVersionIterator]
+                    res.append(self.site+'\t'+self.host+'\t'+self.operating_system+'\t'+self.service_type+'\t'+self.service_names[serviceIterator]+'\t'+tagsDecoded+'\n')
                     serviceVersionIterator = serviceVersionIterator +1
             return res
         else:
